@@ -179,7 +179,7 @@ def get_DC_compatible_date(period: str) -> Optional[Tuple[int, str, int]]:
 
     # Working examples:
     >>> get_DC_compatible_date("2014")
-    2014, A, 1 
+    2014, Y, 1 
     >>> get_DC_compatible_date("2014-S1")
     2014, Q, 2
     >>> get_DC_compatible_date("2014-Q1")
@@ -198,7 +198,7 @@ def get_DC_compatible_date(period: str) -> Optional[Tuple[int, str, int]]:
             if freq == period_format:
                 m = regex.match(period)
                 if freq == Frequency.ANNUAL:
-                    return int(m.group(1)), freq.to_dimension_code(), 1
+                    return int(m.group(1)), "Y", 1
                 elif freq == Frequency.BI_ANNUAL:
                     return int(m.group(1)), "Q", int(m.group(2)) * 2
                 else:
