@@ -115,9 +115,14 @@ def downloadIfNewerThanLocal(sourceURL: str, targetPath: str):
             logger.error('http error for: {}; code: {}; {}'.format(targetPath, e.code, e.info))
 
     else:
-        f = open(targetPath, 'wb')
-        f.write(u.read())
-        f.close()
+        CHUNK = 16 * 1024
+        with open(targetPath, 'wb') as f:
+            while True:
+                chunk = u.read(CHUNK)
+                if not chunk:
+                    break
+                f.write(chunk)
+
     
 
         
